@@ -485,3 +485,36 @@ void AssetPanel::assetPanelWarning(const QString service, const QString /*id*/,
     m_infoMessage->setMessageType(KMessageWidget::Warning);
     m_infoMessage->animatedShow();
 }
+
+void AssetPanel::slotAddRemoveKeyframe()
+{
+    if (m_effectStackWidget->isVisible()) {
+        m_effectStackWidget->addRemoveKeyframe();
+    } else if (m_transitionWidget->isVisible()) {
+        m_transitionWidget->addRemoveKeyframe();
+    } else if (m_mixWidget->isVisible()) {
+        m_mixWidget->addRemoveKeyframe();
+    }
+}
+
+void AssetPanel::slotNextKeyframe()
+{
+    if (m_effectStackWidget->isVisible()) {
+        m_effectStackWidget->slotGoToKeyframe(true);
+    } else if (m_transitionWidget->isVisible()) {
+        m_transitionWidget->nextKeyframe();
+    } else if (m_mixWidget->isVisible()) {
+        m_mixWidget->nextKeyframe();
+    }
+}
+
+void AssetPanel::slotPreviousKeyframe()
+{
+    if (m_effectStackWidget->isVisible()) {
+        m_effectStackWidget->slotGoToKeyframe(false);
+    } else if (m_transitionWidget->isVisible()) {
+        m_transitionWidget->previousKeyframe();
+    } else if (m_mixWidget->isVisible()) {
+        m_mixWidget->previousKeyframe();
+    }
+}
