@@ -218,7 +218,7 @@ const QString ClipCreator::createClipsFromList(const QList<QUrl> &list, bool che
                                       Fun &undo, Fun &redo, bool topLevel)
 {
     QString createdItem;
-    QScopedPointer<QProgressDialog> progressDialog;
+    /*QScopedPointer<QProgressDialog> progressDialog;
     if (topLevel) {
         progressDialog.reset(new QProgressDialog(pCore->window()));
         progressDialog->setWindowTitle(i18n("Loading clips"));
@@ -228,11 +228,29 @@ const QString ClipCreator::createClipsFromList(const QList<QUrl> &list, bool che
         progressDialog->show();
         progressDialog->repaint();
         qApp->processEvents();
+    }*/
+    // Check for duplicates
+    QList<QUrl> cleanList;
+    QStringList duplicates;
+    for (const QUrl &url : list) {
+        if (!pCore->projectItemModel()->urlExists(url.toLocalFile())) {
+            cleanList << url;
+        } else {
+            duplicates << url.toLocalFile();
+        }
     }
-    qDebug() << "/////////// creatclipsfromlist" << list << checkRemovable << parentFolder;
+    if (!duplicates.isEmpty()) {
+        if (KMessageBox::warningYesNoList(QApplication::activeWindow(), i18n("The following clips are already inserted in the project. Do you want to duplicate them?"), duplicates) ==
+                KMessageBox::Yes) {
+                cleanList = list;
+            }
+    }
+
+    qDebug() << "/////////// creatclipsfromlist" << cleanList << checkRemovable << parentFolder;
     bool created = false;
     QMimeDatabase db;
-    for (const QUrl &file : list) {
+    bool removableProject = checkRemovable ? isOnRemovableDevice(pCore->currentDoc()->projectDataFolder()) : false;
+    for (const QUrl &file : cleanList) {
         if (!QFile::exists(file.toLocalFile())) {
             continue;
         }
@@ -303,7 +321,7 @@ const QString ClipCreator::createClipsFromList(const QList<QUrl> &list, bool che
             }
         } else {
             // file is not a directory
-            if (checkRemovable && isOnRemovableDevice(file) && !isOnRemovableDevice(pCore->currentDoc()->projectDataFolder())) {
+            if (checkRemovable && isOnRemovableDevice(file) && !removableProject) {
                 int answer = KMessageBox::warningContinueCancel(
                     QApplication::activeWindow(),
                     i18n("Clip <b>%1</b><br /> is on a removable device, will not be available when device is unplugged or mounted at a different position.\nYou "
@@ -318,6 +336,7 @@ const QString ClipCreator::createClipsFromList(const QList<QUrl> &list, bool che
                 createdItem = clipId;
             }
         }
+        //qApp->processEvents();
     }
     qDebug() << "/////////// creatclipsfromlist return" << created;
     return createdItem == QLatin1String("-1") ? QString() : createdItem;
