@@ -27,11 +27,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "doc/kdenlivedoc.h"
 #include "doc/kthumb.h"
 #include "effects/effectstack/model/effectstackmodel.hpp"
-#include "jobs/audiothumbjob.hpp"
-#include "jobs/jobmanager.h"
-#include "jobs/loadjob.hpp"
-#include "jobs/thumbjob.hpp"
-#include "jobs/cachejob.hpp"
+#include "jobs/audiolevelstask.h"
+#include "jobs/cliploadtask.h"
+#include "jobs/proxytask.h"
+#include "jobs/cachetask.h"
 #include "kdenlivesettings.h"
 #include "lib/audio/audioStreamInfo.h"
 #include "mltcontroller/clipcontroller.h"
@@ -45,11 +44,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "projectsubclip.h"
 #include "timecode.h"
 #include "timeline2/model/snapmodel.hpp"
+#include "macros.hpp"
 
 #include "utils/thumbnailcache.hpp"
 #include "xml/xml.hpp"
 #include <QPainter>
-#include <jobs/proxyclipjob.h>
 #include <kimagecache.h>
 
 #include "kdenlive_debug.h"
@@ -120,6 +119,12 @@ ProjectClip::ProjectClip(const QString &id, const QIcon &thumb, const std::share
     setTags(getProducerProperty(QStringLiteral("kdenlive:tags")));
     AbstractProjectItem::setRating(uint(getProducerIntProperty(QStringLiteral("kdenlive:rating"))));
     connectEffectStack();
+    if (m_clipStatus == FileStatus::StatusProxy || m_clipStatus == FileStatus::StatusReady || m_clipStatus == FileStatus::StatusProxyOnly) {
+        // Generate clip thumbnail
+        ClipLoadTask::start({ObjectType::BinClip,m_binId.toInt()}, QDomElement(), true, -1, -1, this);
+        // Generate audio thumbnail
+        AudioLevelsTask::start({ObjectType::BinClip, m_binId.toInt()}, this, false);
+    }
 }
 
 // static
@@ -173,11 +178,6 @@ std::shared_ptr<ProjectClip> ProjectClip::construct(const QString &id, const QDo
 
 ProjectClip::~ProjectClip()
 {
-    // controller is deleted in bincontroller
-    m_thumbMutex.lock();
-    m_requestedThumbs.clear();
-    m_thumbMutex.unlock();
-    m_thumbThread.waitForFinished();
 }
 
 void ProjectClip::connectEffectStack()
@@ -216,7 +216,7 @@ void ProjectClip::updateAudioThumbnail()
     emit audioThumbReady();
     if (m_clipType == ClipType::Audio) {
         QImage thumb = ThumbnailCache::get()->getThumbnail(m_binId, 0);
-        if (thumb.isNull()) {
+        if (thumb.isNull() && !pCore->taskManager.hasPendingJob({ObjectType::BinClip, m_binId.toInt()}, AbstractTask::AUDIOTHUMBJOB)) {
             int iconHeight = int(QFontInfo(qApp->font()).pixelSize() * 3.5);
             QImage img(QSize(int(iconHeight * pCore->getCurrentDar()), iconHeight), QImage::Format_ARGB32);
             img.fill(Qt::darkGray);
@@ -257,7 +257,9 @@ void ProjectClip::updateAudioThumbnail()
             // Cache thumbnail
             ThumbnailCache::get()->storeThumbnail(m_binId, 0, thumb, true);
         }
-        setThumbnail(thumb);
+        if (!thumb.isNull()) {
+            setThumbnail(thumb, -1, -1);
+        }
     }
     if (!KdenliveSettings::audiothumbnails()) {
         return;
@@ -369,28 +371,27 @@ size_t ProjectClip::frameDuration() const
 void ProjectClip::reloadProducer(bool refreshOnly, bool isProxy, bool forceAudioReload)
 {
     // we find if there are some loading job on that clip
-    int loadjobId = -1;
-    pCore->jobManager()->hasPendingJob(clipId(), AbstractClipJob::LOADJOB, &loadjobId);
     QMutexLocker lock(&m_thumbMutex);
     if (refreshOnly) {
         // In that case, we only want a new thumbnail.
         // We thus set up a thumb job. We must make sure that there is no pending LOADJOB
         // Clear cache first
         ThumbnailCache::get()->invalidateThumbsForClip(clipId());
-        pCore->jobManager()->discardJobs(clipId(), AbstractClipJob::THUMBJOB);
+        pCore->taskManager.discardJobs({ObjectType::BinClip, m_binId.toInt()}, AbstractTask::LOADJOB, true);
+        pCore->taskManager.discardJobs({ObjectType::BinClip, m_binId.toInt()}, AbstractTask::CACHEJOB);
         m_thumbsProducer.reset();
-        emit pCore->jobManager()->startJob<ThumbJob>({clipId()}, loadjobId, QString(), -1, true, true);
+        ClipLoadTask::start({ObjectType::BinClip,m_binId.toInt()}, QDomElement(), true, -1, -1, this);
     } else {
         // If another load job is running?
-        pCore->jobManager()->discardJobs(clipId());
-        if (QFile::exists(m_path) && !hasProxy()) {
+        pCore->taskManager.discardJobs({ObjectType::BinClip, m_binId.toInt()}, AbstractTask::LOADJOB, true);
+        pCore->taskManager.discardJobs({ObjectType::BinClip, m_binId.toInt()}, AbstractTask::CACHEJOB);
+        if (QFile::exists(m_path) && (!isProxy && !hasProxy())) {
             clearBackupProperties();
         }
         QDomDocument doc;
         QDomElement xml = toXml(doc);
         if (!xml.isNull()) {
             bool hashChanged = false;
-            pCore->jobManager()->discardJobs(clipId(), AbstractClipJob::THUMBJOB);
             m_thumbsProducer.reset();
             ClipType::ProducerType type = clipType();
             if (type != ClipType::Color && type != ClipType::Image && type != ClipType::SlideShow) {
@@ -405,17 +406,12 @@ void ProjectClip::reloadProducer(bool refreshOnly, bool isProxy, bool forceAudio
                         hashChanged = true;
                     }
                 }
-                
             }
             ThumbnailCache::get()->invalidateThumbsForClip(clipId());
-            int loadJob = pCore->jobManager()->startJob<LoadJob>({clipId()}, loadjobId, QString(), xml);
-            emit pCore->jobManager()->startJob<ThumbJob>({clipId()}, loadJob, QString(), -1, true, true);
             if (forceAudioReload || (!isProxy && hashChanged)) {
                 discardAudioThumb();
             }
-            if (KdenliveSettings::audiothumbnails()) {
-                emit pCore->jobManager()->startJob<AudioThumbJob>({clipId()}, loadJob, QString());
-            }
+            ClipLoadTask::start({ObjectType::BinClip,m_binId.toInt()}, xml, false, -1, -1, this);
         }
     }
 }
@@ -435,11 +431,18 @@ QDomElement ProjectClip::toXml(QDomDocument &document, bool includeMeta, bool in
     return prod;
 }
 
-void ProjectClip::setThumbnail(const QImage &img)
+void ProjectClip::setThumbnail(const QImage &img, int in, int out)
 {
     if (img.isNull()) {
         return;
     }
+    if (in > -1) {
+        std::shared_ptr<ProjectSubClip> sub = getSubClip(in, out);
+        if (sub) {
+            sub->setThumbnail(img);
+        }
+        return;
+    }
     QPixmap thumb = roundedPixmap(QPixmap::fromImage(img));
     if (hasProxy() && !thumb.isNull()) {
         // Overlay proxy icon
@@ -483,14 +486,17 @@ QPixmap ProjectClip::thumbnail(int width, int height)
     return m_thumbnail.pixmap(width, height);
 }
 
-bool ProjectClip::setProducer(std::shared_ptr<Mlt::Producer> producer, bool replaceProducer)
+bool ProjectClip::setProducer(std::shared_ptr<Mlt::Producer> producer)
 {
-    Q_UNUSED(replaceProducer)
     qDebug() << "################### ProjectClip::setproducer";
     QMutexLocker locker(&m_producerMutex);
     FileStatus::ClipStatus currentStatus = m_clipStatus;
     updateProducer(producer);
     emit producerChanged(m_binId, producer);
+    if (producer->get_int("kdenlive:transcodingrequired") == 1) {
+        pCore->bin()->requestTranscoding(clipUrl(), clipId());
+        producer->set("kdenlive:transcodingrequired", nullptr);
+    }
     m_thumbsProducer.reset();
     connectEffectStack();
 
@@ -525,9 +531,27 @@ bool ProjectClip::setProducer(std::shared_ptr<Mlt::Producer> producer, bool repl
     getFileHash();
     // set parent again (some info need to be stored in producer)
     updateParent(parentItem().lock());
-
+    AudioLevelsTask::start({ObjectType::BinClip, m_binId.toInt()}, this, false);
+    pCore->bin()->reloadMonitorIfActive(clipId());
+    for (auto &p : m_audioProducers) {
+        m_effectStack->removeService(p.second);
+    }
+    for (auto &p : m_videoProducers) {
+        m_effectStack->removeService(p.second);
+    }
+    for (auto &p : m_timewarpProducers) {
+        m_effectStack->removeService(p.second);
+    }
+    // Release audio producers
+    m_audioProducers.clear();
+    m_videoProducers.clear();
+    m_timewarpProducers.clear();
+    emit refreshPropertiesPanel();
+    replaceInTimeline();
+    updateTimelineClips({TimelineModel::IsProxyRole});
+    bool generateProxy = false;
+    QList<std::shared_ptr<ProjectClip>> clipList;
     if (pCore->currentDoc()->getDocumentProperty(QStringLiteral("enableproxy")).toInt() == 1) {
-        QList<std::shared_ptr<ProjectClip>> clipList;
         // automatic proxy generation enabled
         if (m_clipType == ClipType::Image && pCore->currentDoc()->getDocumentProperty(QStringLiteral("generateimageproxy")).toInt() == 1) {
             if (getProducerIntProperty(QStringLiteral("meta.media.width")) >= KdenliveSettings::proxyimageminsize() &&
@@ -563,50 +587,34 @@ bool ProjectClip::setProducer(std::shared_ptr<Mlt::Producer> producer, bool repl
             }
         }
         if (!clipList.isEmpty()) {
-            pCore->currentDoc()->slotProxyCurrentItem(true, clipList, false);
+            generateProxy = true;
         }
     }
-    pCore->bin()->reloadMonitorIfActive(clipId());
-    for (auto &p : m_audioProducers) {
-        m_effectStack->removeService(p.second);
-    }
-    for (auto &p : m_videoProducers) {
-        m_effectStack->removeService(p.second);
-    }
-    for (auto &p : m_timewarpProducers) {
-        m_effectStack->removeService(p.second);
-    }
-    // Release audio producers
-    m_audioProducers.clear();
-    m_videoProducers.clear();
-    m_timewarpProducers.clear();
-    emit refreshPropertiesPanel();
-    if (KdenliveSettings::hoverPreview() && (m_clipType == ClipType::AV || m_clipType == ClipType::Video || m_clipType == ClipType::Playlist)) {
+    if (!generateProxy && KdenliveSettings::hoverPreview() && (m_clipType == ClipType::AV || m_clipType == ClipType::Video || m_clipType == ClipType::Playlist)) {
         QTimer::singleShot(1000, this, [this]() {
-            int loadjobId;
-            if (!pCore->jobManager()->hasPendingJob(m_binId, AbstractClipJob::CACHEJOB, &loadjobId)) {
-                emit pCore->jobManager()->startJob<CacheJob>({m_binId}, -1, QString());
-            }
+            CacheTask::start({ObjectType::BinClip,m_binId.toInt()}, 30, 0, 0, this);
         });
     }
-    replaceInTimeline();
-    updateTimelineClips({TimelineModel::IsProxyRole});
+    if (generateProxy) {
+        QMetaObject::invokeMethod(pCore->currentDoc(), "slotProxyCurrentItem", Q_ARG(bool,true), Q_ARG(QList<std::shared_ptr<ProjectClip>>,clipList), Q_ARG(bool,false));
+    }
     return true;
 }
 
+void ProjectClip::setThumbProducer(std::shared_ptr<Mlt::Producer>prod)
+{
+    m_thumbsProducer = std::move(prod);
+}
+
 std::shared_ptr<Mlt::Producer> ProjectClip::thumbProducer()
 {
     if (m_thumbsProducer) {
         return m_thumbsProducer;
     }
-    if (clipType() == ClipType::Unknown) {
+    if (clipType() == ClipType::Unknown || m_masterProducer == nullptr) {
         return nullptr;
     }
     QMutexLocker lock(&m_thumbMutex);
-    std::shared_ptr<Mlt::Producer> prod = originalProducer();
-    if (!prod->is_valid()) {
-        return nullptr;
-    }
     if (KdenliveSettings::gpu_accel()) {
         // TODO: when the original producer changes, we must reload this thumb producer
         m_thumbsProducer = softClone(ClipController::getPassPropertiesList());
@@ -714,12 +722,12 @@ int ProjectClip::getRecordTime()
     return 0;
 }
 
-std::shared_ptr<Mlt::Producer> ProjectClip::getTimelineProducer(int trackId, int clipId, PlaylistState::ClipState state, int audioStream, double speed, bool secondPlaylist)
+std::shared_ptr<Mlt::Producer> ProjectClip::getTimelineProducer(int trackId, int clipId, PlaylistState::ClipState state, int audioStream, double speed, bool secondPlaylist, bool timeremap)
 {
     if (!m_masterProducer) {
         return nullptr;
     }
-    if (qFuzzyCompare(speed, 1.0)) {
+    if (qFuzzyCompare(speed, 1.0) && !timeremap) {
         // we are requesting a normal speed producer
         bool byPassTrackProducer = false;
         if (trackId == -1 && (state != PlaylistState::AudioOnly || audioStream == m_masterProducer->get_int("audio_index"))) {
@@ -806,7 +814,7 @@ std::shared_ptr<Mlt::Producer> ProjectClip::getTimelineProducer(int trackId, int
     if (m_timewarpProducers.count(clipId) > 0) {
         // remove in all cases, we add it unconditionally anyways
         m_effectStack->removeService(m_timewarpProducers[clipId]);
-        if (qFuzzyCompare(m_timewarpProducers[clipId]->get_double("warp_speed"), speed)) {
+        if (qFuzzyCompare(m_timewarpProducers[clipId]->get_double("warp_speed"), speed) || timeremap) {
             // the producer we have is good, use it !
             warpProducer = m_timewarpProducers[clipId];
             qDebug() << "Reusing producer!";
@@ -819,16 +827,23 @@ std::shared_ptr<Mlt::Producer> ProjectClip::getTimelineProducer(int trackId, int
         if (resource.isEmpty() || resource == QLatin1String("<producer>")) {
             resource = m_service;
         }
-        QString url = QString("timewarp:%1:%2").arg(QString::fromStdString(std::to_string(speed)), resource);
-        warpProducer.reset(new Mlt::Producer(*originalProducer()->profile(), url.toUtf8().constData()));
-        qDebug() << "new producer: " << url;
-        qDebug() << "warp LENGTH before" << warpProducer->get_length();
-        int original_length = originalProducer()->get_length();
+        if (timeremap) {
+            Mlt::Chain *chain = new Mlt::Chain(*originalProducer()->profile(), resource.toUtf8().constData());
+            Mlt::Link link("timeremap");
+            chain->attach(link);
+            warpProducer.reset(chain);
+        } else {
+            QString url = QString("timewarp:%1:%2").arg(QString::fromStdString(std::to_string(speed)), resource);
+            warpProducer.reset(new Mlt::Producer(*originalProducer()->profile(), url.toUtf8().constData()));
+            int original_length = originalProducer()->get_length();
+            warpProducer->set("length", int(original_length / std::abs(speed) + 0.5));
+            qDebug() << "new producer: " << url;
+            qDebug() << "warp LENGTH before" << warpProducer->get_length();
+        }
         // this is a workaround to cope with Mlt erroneous rounding
         Mlt::Properties original(m_masterProducer->get_properties());
         Mlt::Properties cloneProps(warpProducer->get_properties());
         cloneProps.pass_list(original, ClipController::getPassPropertiesList(false));
-        warpProducer->set("length", int(original_length / std::abs(speed) + 0.5));
         warpProducer->set("audio_index", audioStream);
     }
 
@@ -866,6 +881,8 @@ std::pair<std::shared_ptr<Mlt::Producer>, bool> ProjectClip::giveMasterAndGetTim
         if (QString::fromUtf8(master->parent().get("mlt_service")) == QLatin1String("timewarp")) {
             speed = master->parent().get_double("warp_speed");
             timeWarp = true;
+        } else if (master->parent().type() == mlt_service_chain_type) {
+            timeWarp = true;
         }
         if (master->parent().get_int("_loaded") == 1) {
             // we already have a clip that shares the same master
@@ -944,7 +961,19 @@ std::pair<std::shared_ptr<Mlt::Producer>, bool> ProjectClip::giveMasterAndGetTim
 std::shared_ptr<Mlt::Producer> ProjectClip::cloneProducer(bool removeEffects)
 {
     Mlt::Consumer c(pCore->getCurrentProfile()->profile(), "xml", "string");
-    Mlt::Service s(m_masterProducer->get_service());
+    Mlt::Service s;
+    bool playlistChain = false;
+    QScopedPointer<Mlt::Service> serv;
+    if (m_clipType == ClipType::Playlist) {
+        serv.reset(m_masterProducer->producer());
+        if (serv != nullptr) {
+            s = Mlt::Service(serv->get_service());
+            playlistChain = true;
+        }
+    }
+    if (!playlistChain) {
+        s = Mlt::Service(m_masterProducer->get_service());
+    }
     int ignore = s.get_int("ignore_points");
     if (ignore) {
         s.set("ignore_points", 0);
@@ -962,6 +991,7 @@ std::shared_ptr<Mlt::Producer> ProjectClip::cloneProducer(bool removeEffects)
     }
     const QByteArray clipXml = c.get("string");
     std::shared_ptr<Mlt::Producer> prod;
+    qDebug()<<"============= CLONED CLIP: \n\n"<<clipXml<<"\n\n======================";
     prod.reset(new Mlt::Producer(pCore->getCurrentProfile()->profile(), "xml-string", clipXml.constData()));
 
     if (strcmp(prod->get("mlt_service"), "avformat") == 0) {
@@ -1209,13 +1239,13 @@ void ProjectClip::setProperties(const QMap<QString, QString> &properties, bool r
         // Clip source was changed, update important stuff
         refreshPanel = true;
         reload = true;
+        resetProducerProperty(QStringLiteral("kdenlive:file_hash"));
         if (m_clipType == ClipType::Color) {
             refreshOnly = true;
             updateRoles << TimelineModel::ResourceRole;
         } else if (!properties.contains("kdenlive:proxy")) {
             // Clip resource changed, update thumbnail, name, clear hash
             refreshOnly = false;
-            resetProducerProperty(QStringLiteral("kdenlive:file_hash"));
             getInfoForProducer();
             updateRoles << TimelineModel::ResourceRole << TimelineModel::MaxDurationRole << TimelineModel::NameRole;
         }
@@ -1226,9 +1256,9 @@ void ProjectClip::setProperties(const QMap<QString, QString> &properties, bool r
         if (value.isEmpty() || value == QLatin1String("-")) {
             // reset proxy
             int id;
-            if (pCore->jobManager()->hasPendingJob(clipId(), AbstractClipJob::PROXYJOB, &id)) {
+            if (pCore->taskManager.hasPendingJob({ObjectType::BinClip, m_binId.toInt()}, AbstractTask::PROXYJOB)) {
                 // The proxy clip is being created, abort
-                pCore->jobManager()->discardJobs(clipId(), AbstractClipJob::PROXYJOB);
+                pCore->taskManager.discardJobs({ObjectType::BinClip, m_binId.toInt()}, AbstractTask::PROXYJOB);
             } else {
                 reload = true;
                 refreshOnly = false;
@@ -1237,7 +1267,7 @@ void ProjectClip::setProperties(const QMap<QString, QString> &properties, bool r
             // A proxy was requested, make sure to keep original url
             setProducerProperty(QStringLiteral("kdenlive:originalurl"), url());
             backupOriginalProperties();
-            emit pCore->jobManager()->startJob<ProxyJob>({clipId()}, -1, QString());
+            ProxyTask::start({ObjectType::BinClip,m_binId.toInt()}, this);
         }
     } else if (!reload) {
         const QList<QString> propKeys = properties.keys();
@@ -1296,9 +1326,9 @@ void ProjectClip::setProperties(const QMap<QString, QString> &properties, bool r
     if (reload) {
         // producer has changed, refresh monitor and thumbnail
         if (hasProxy()) {
-            pCore->jobManager()->discardJobs(clipId(), AbstractClipJob::PROXYJOB);
+            pCore->taskManager.discardJobs({ObjectType::BinClip, m_binId.toInt()}, AbstractTask::PROXYJOB);
             setProducerProperty(QStringLiteral("_overwriteproxy"), 1);
-            emit pCore->jobManager()->startJob<ProxyJob>({clipId()}, -1, QString());
+            ProxyTask::start({ObjectType::BinClip,m_binId.toInt()}, this);
         } else {
             reloadProducer(refreshOnly, properties.contains(QStringLiteral("kdenlive:proxy")));
         }
@@ -1473,7 +1503,7 @@ void ProjectClip::discardAudioThumb()
     if (!m_audioInfo) {
         return;
     }
-    pCore->jobManager()->discardJobs(clipId(), AbstractClipJob::AUDIOTHUMBJOB);
+    pCore->taskManager.discardJobs({ObjectType::BinClip, m_binId.toInt()}, AbstractTask::AUDIOTHUMBJOB);
     QString audioThumbPath;
     QList <int> streams = m_audioInfo->streams().keys();
     // Delete audio thumbnail data
@@ -1544,7 +1574,8 @@ QStringList ProjectClip::updatedAnalysisData(const QString &name, const QString
         if (KMessageBox::questionYesNo(QApplication::activeWindow(), i18n("Clip already contains analysis data %1", name), QString(), KGuiItem(i18n("Merge")),
                                        KGuiItem(i18n("Add"))) == KMessageBox::Yes) {
             // Merge data
-            auto &profile = pCore->getCurrentProfile();
+            //TODO MLT7: convert to Mlt::Animation
+            /*auto &profile = pCore->getCurrentProfile();
             Mlt::Geometry geometry(current.toUtf8().data(), duration().frames(profile->fps()), profile->width(), profile->height());
             Mlt::Geometry newGeometry(data.toUtf8().data(), duration().frames(profile->fps()), profile->width(), profile->height());
             Mlt::GeometryItem item;
@@ -1555,7 +1586,7 @@ QStringList ProjectClip::updatedAnalysisData(const QString &name, const QString
                 pos++;
                 geometry.insert(item);
             }
-            return QStringList() << QString("kdenlive:clipanalysis." + name) << geometry.serialise();
+            return QStringList() << QString("kdenlive:clipanalysis." + name) << geometry.serialise();*/
             // m_controller->setProperty("kdenlive:clipanalysis." + name, geometry.serialise());
         }
         // Add data with another name
@@ -1583,7 +1614,8 @@ const QString ProjectClip::geometryWithOffset(const QString &data, int offset)
         return data;
     }
     auto &profile = pCore->getCurrentProfile();
-    Mlt::Geometry geometry(data.toUtf8().data(), duration().frames(profile->fps()), profile->width(), profile->height());
+    // TODO MLT7: port to Mlt::Animation
+    /*Mlt::Geometry geometry(data.toUtf8().data(), duration().frames(profile->fps()), profile->width(), profile->height());
     Mlt::Geometry newgeometry(nullptr, duration().frames(profile->fps()), profile->width(), profile->height());
     Mlt::GeometryItem item;
     int pos = 0;
@@ -1594,6 +1626,8 @@ const QString ProjectClip::geometryWithOffset(const QString &data, int offset)
         newgeometry.insert(item);
     }
     return newgeometry.serialise();
+    */
+    return QString();
 }
 
 bool ProjectClip::isSplittable() const
@@ -1659,6 +1693,18 @@ QList<int> ProjectClip::timelineInstances() const
 
 bool ProjectClip::selfSoftDelete(Fun &undo, Fun &redo)
 {
+    Fun operation = [this]() {
+        // Free audio thumb data and timeline producers
+        pCore->taskManager.discardJobs({ObjectType::BinClip, m_binId.toInt()});
+        m_audioLevels.clear();
+        m_disabledProducer.reset();
+        m_audioProducers.clear();
+        m_videoProducers.clear();
+        m_timewarpProducers.clear();
+        return true;
+    };
+    operation();
+
     auto toDelete = m_registeredClips; // we cannot use m_registeredClips directly, because it will be modified during loop
     for (const auto &clip : toDelete) {
         if (m_registeredClips.count(clip.first) == 0) {
@@ -1674,9 +1720,22 @@ bool ProjectClip::selfSoftDelete(Fun &undo, Fun &redo)
             return false;
         }
     }
+    PUSH_LAMBDA(operation, redo);
+    qDebug()<<"===== REMOVING MASTER PRODUCER; CURRENT COUNT: "<<m_masterProducer.use_count()<<"\n:::::::::::::::::::::::::::";
     return AbstractProjectItem::selfSoftDelete(undo, redo);
 }
 
+Fun ProjectClip::getAudio_lambda()
+{
+    return [this]() {
+        if (KdenliveSettings::audiothumbnails() && (m_clipType == ClipType::AV || m_clipType == ClipType::Audio || m_clipType == ClipType::Playlist) && m_audioLevels.isEmpty()) {
+            // Generate audio levels
+            AudioLevelsTask::start({ObjectType::BinClip, m_binId.toInt()}, this, false);
+        }
+        return true;
+    };
+}
+
 bool ProjectClip::isIncludedInTimeline()
 {
     return m_registeredClips.size() > 0;
@@ -1743,17 +1802,14 @@ void ProjectClip::getThumbFromPercent(int percent)
 {
     // extract a maximum of 30 frames for bin preview
     int duration = getFramePlaytime();
-    int steps = qCeil(qMax(pCore->getCurrentFps(), double(duration / 30)));
+    int steps = qCeil(qMax(pCore->getCurrentFps(), double(duration) / 30));
     int framePos = duration * percent / 100;
     framePos -= framePos%steps;
     if (ThumbnailCache::get()->hasThumbnail(m_binId, framePos)) {
-        setThumbnail(ThumbnailCache::get()->getThumbnail(m_binId, framePos));
+        setThumbnail(ThumbnailCache::get()->getThumbnail(m_binId, framePos), -1, -1);
     } else {
         // Generate percent thumbs
-        int id;
-        if (!pCore->jobManager()->hasPendingJob(m_binId, AbstractClipJob::CACHEJOB, &id)) {
-            emit pCore->jobManager()->startJob<CacheJob>({m_binId}, -1, QString());
-        }
+        CacheTask::start({ObjectType::BinClip,m_binId.toInt()}, 30, 0, 0, this);
     }
 }
 
@@ -1764,6 +1820,26 @@ void ProjectClip::setRating(uint rating)
     pCore->currentDoc()->setModified(true);
 }
 
+int ProjectClip::getAudioMax(int stream)
+{
+    const QString key = QString("kdenlive:audio_max%1").arg(stream);
+    if (m_masterProducer->property_exists(key.toUtf8().constData())) {
+        return m_masterProducer->get_int(key.toUtf8().constData());
+    }
+    // Process audio max for the stream
+    const QString key2 = QString("_kdenlive:audio%1").arg(stream);
+    if (!m_masterProducer->property_exists(key2.toUtf8().constData())) {
+        return 0;
+    }
+    const QVector <uint8_t> audioData = *static_cast<QVector<uint8_t> *>(m_masterProducer->get_data(key2.toUtf8().constData()));
+    if (audioData.isEmpty()) {
+        return 0;
+    }
+    uint max = *std::max_element(audioData.constBegin(), audioData.constEnd());
+    m_masterProducer->set(key.toUtf8().constData(), int(max));
+    return int(max);
+}
+
 const QVector <uint8_t> ProjectClip::audioFrameCache(int stream)
 {
     QVector <uint8_t> audioLevels;
@@ -1774,7 +1850,16 @@ const QVector <uint8_t> ProjectClip::audioFrameCache(int stream)
             return audioLevels;
         }
     }
-    QString key = QString("%1:%2").arg(m_binId).arg(stream);
+    const QString key = QString("_kdenlive:audio%1").arg(stream);
+    if (m_masterProducer->get_data(key.toUtf8().constData())) {
+        const QVector <uint8_t> audioData = *static_cast<QVector<uint8_t> *>(m_masterProducer->get_data(key.toUtf8().constData()));
+        return audioData;
+    } else {
+        qDebug()<<"=== AUDIO NOT FOUND ";
+    }
+    return QVector <uint8_t>();
+    
+    /*QString key = QString("%1:%2").arg(m_binId).arg(stream);
     QByteArray audioData;
     if (pCore->audioThumbCache.find(key, &audioData)) {
         if (audioData != QByteArray("-")) {
@@ -1802,7 +1887,7 @@ const QVector <uint8_t> ProjectClip::audioFrameCache(int stream)
         st << audioLevels;
         pCore->audioThumbCache.insert(key, audioData);
     }
-    return audioLevels;
+    return audioLevels;*/
 }
 
 void ProjectClip::setClipStatus(FileStatus::ClipStatus status)
@@ -2006,3 +2091,28 @@ void ProjectClip::updateTimelineOnReload()
         }
     }
 }
+
+void ProjectClip::updateJobProgress()
+{
+    if (auto ptr = m_model.lock()) {
+        std::static_pointer_cast<ProjectItemModel>(ptr)->onItemUpdated(m_binId, AbstractProjectItem::JobProgress);
+    }
+}
+
+void ProjectClip::setInvalid()
+{
+    m_isInvalid = true;
+    m_producerLock.unlock();
+}
+
+void ProjectClip::updateProxyProducer(const QString &path)
+{
+    setProducerProperty(QStringLiteral("_overwriteproxy"), QString());
+    setProducerProperty(QStringLiteral("resource"), path);
+    reloadProducer(false, true);
+}
+
+void ProjectClip::importJsonMarkers(const QString &json)
+{
+    getMarkerModel()->importFromJson(json, true);
+}
