@@ -51,7 +51,6 @@ class Tractor;
  * @class ProjectItemModel
  * @brief Acts as an adaptor to be able to use BinModel with item views.
  */
-
 class ProjectItemModel : public AbstractTreeModel
 {
     Q_OBJECT
@@ -72,7 +71,7 @@ public:
     std::shared_ptr<ProjectClip> getClipByBinID(const QString &binId);
     /** @brief Returns audio levels for a clip from its id */
     const QVector <uint8_t>getAudioLevelsByBinID(const QString &binId, int stream);
-    double getAudioMaxLevel(const QString &binId);
+    double getAudioMaxLevel(const QString &binId, int stream);
 
     /** @brief Returns a list of clips using the given url */
     QStringList getClipByUrl(const QFileInfo &url) const;
@@ -160,7 +159,7 @@ public:
        @param description Xml description of the clip
        @param parentId Bin id of the parent folder
        @param undo,redo: lambdas that are updated to accumulate operation.
-       @parame readyCallBack: lambda that will be executed when the clip becomes ready. It is given the binId as parameter
+       @param readyCallBack: lambda that will be executed when the clip becomes ready. It is given the binId as parameter
     */
     bool requestAddBinClip(QString &id, const QDomElement &description, const QString &parentId, Fun &undo, Fun &redo,
                            const std::function<void(const QString &)> &readyCallBack = [](const QString &) {});
@@ -190,6 +189,9 @@ public:
     /** @brief Request that the unused clips are deleted */
     bool requestCleanupUnused();
 
+    /** @brief Request that all clips using one of the given urls are removed from the project and deleted from the hard disk*/
+    bool requestTrashClips(QStringList &urls);
+
     /** @brief Retrieves the next id available for attribution to a folder */
     int getFreeFolderId();
 
@@ -209,13 +211,15 @@ public:
     void setClipWaiting(const QString &binId);
     void setClipInvalid(const QString &binId);
 
-    /** @brief Returns true if current project has a clip with id @clipId and a hash of @clipHash */
+    /** @brief Returns true if current project has a clip with id \@clipId and a hash of \@clipHash */
     bool validateClip(const QString &binId, const QString &clipHash);
-    /** @brief Returns clip id if folder @folderId has a clip with hash of @clipHash or empty if not found */
+    /** @brief Returns clip id if folder "folderId" has a clip with hash of "clipHash" or empty if not found */
     QString validateClipInFolder(const QString &folderId, const QString &clipHash);
 
     /** @brief Number of clips in the bin playlist */
     int clipsCount() const;
+    /** @brief Check if  a file is already in Bin */
+    bool urlExists(const QString &path) const;
 
 protected:
     /** @brief Register the existence of a new element
