@@ -14,7 +14,6 @@ the Free Software Foundation, either version 3 of the License, or
 #include "capture/mediacapture.h"
 #include "doc/docundostack.hpp"
 #include "doc/kdenlivedoc.h"
-#include "jobs/jobmanager.h"
 #include "kdenlive_debug.h"
 #include "kdenlivesettings.h"
 #include "library/librarywidget.h"
@@ -31,6 +30,8 @@ the Free Software Foundation, either version 3 of the License, or
 #include "timeline2/view/timelinewidget.h"
 #include "dialogs/subtitleedit.h"
 #include "dialogs/textbasededit.h"
+#include "dialogs/proxytest.h"
+#include "dialogs/timeremap.h"
 #include <mlt++/MltRepository.h>
 
 #include <KMessageBox>
@@ -46,6 +47,7 @@ the Free Software Foundation, either version 3 of the License, or
 std::unique_ptr<Core> Core::m_self;
 Core::Core()
     : audioThumbCache(QStringLiteral("audioCache"), 2000000)
+    , taskManager(this)
     , m_thumbProfile(nullptr)
     , m_capture(new MediaCapture(this))
 {
@@ -90,6 +92,8 @@ bool Core::build(bool testMode)
     qRegisterMetaType<QVector<int>>();
     qRegisterMetaType<QDomElement>("QDomElement");
     qRegisterMetaType<requestClipInfo>("requestClipInfo");
+    qRegisterMetaType<QVector<QPair<QString, QVariant>>>("paramVector");
+    qRegisterMetaType<ProfileParam*>("ProfileParam*");
     
     if (!testMode) {
         // Check if we had a crash
@@ -109,8 +113,6 @@ bool Core::build(bool testMode)
     }
 
     m_self->m_projectItemModel = ProjectItemModel::construct();
-    // Job manager must be created before bin to correctly connect
-    m_self->m_jobManager.reset(new JobManager(m_self.get()));
     return true;
 }
 
@@ -135,6 +137,7 @@ void Core::initGUI(bool isAppImage, const QString &MltPath, const QUrl &Url, con
     m_subtitleWidget = new SubtitleEdit(m_mainWindow);
     m_mixerWidget = new MixerManager(m_mainWindow);
     m_textEditWidget = new TextBasedEdit(m_mainWindow);
+    m_timeRemapWidget = new TimeRemap(m_mainWindow);
     connect(m_library, SIGNAL(addProjectClips(QList<QUrl>)), m_binWidget, SLOT(droppedUrls(QList<QUrl>)));
     connect(this, &Core::updateLibraryPath, m_library, &LibraryWidget::slotUpdateLibraryPath);
     connect(m_capture.get(), &MediaCapture::recordStateChanged, m_mixerWidget, &MixerManager::recordStateChanged);
@@ -220,7 +223,6 @@ void Core::initGUI(bool isAppImage, const QString &MltPath, const QUrl &Url, con
     }
     QMetaObject::invokeMethod(pCore->projectManager(), "slotLoadOnOpen", Qt::QueuedConnection);
     m_mainWindow->show();
-    QThreadPool::globalInstance()->setMaxThreadCount(qMin(4, QThreadPool::globalInstance()->maxThreadCount()));
 
     // Release startup crash lock file
     QFile lockFile(QDir::temp().absoluteFilePath(QStringLiteral("kdenlivelock")));
@@ -301,11 +303,6 @@ std::shared_ptr<SubtitleModel> Core::getSubtitleModel(bool enforce)
     return nullptr;
 }
 
-std::shared_ptr<JobManager> Core::jobManager()
-{
-    return m_jobManager;
-}
-
 LibraryWidget *Core::library()
 {
     return m_library;
@@ -316,6 +313,11 @@ TextBasedEdit *Core::textEditWidget()
     return m_textEditWidget;
 }
 
+TimeRemap *Core::timeRemapWidget()
+{
+    return m_timeRemapWidget;
+}
+
 SubtitleEdit *Core::subtitleWidget()
 {
     return m_subtitleWidget;
@@ -691,6 +693,11 @@ void Core::displayMessage(const QString &message, MessageType type, int timeout)
     }
 }
 
+void Core::loadingClips(int count)
+{
+    m_mainWindow->displayProgressMessage(i18n("Loading clips"), MessageType::ProcessingJobMessage, count);
+}
+
 void Core::displayBinMessage(const QString &text, int type, const QList<QAction *> &actions, bool showClose, BinMessage::BinCategory messageCategory)
 {
     m_binWidget->doDisplayMessage(text, KMessageWidget::MessageType(type), actions, showClose, messageCategory);
@@ -1037,3 +1044,8 @@ void Core::updateMasterZones()
     }
 }
 
+void Core::testProxies()
+{
+    QScopedPointer<ProxyTest> dialog(new ProxyTest(QApplication::activeWindow()));
+    dialog->exec();
+}
