@@ -12,6 +12,7 @@ the Free Software Foundation, either version 3 of the License, or
 #define CORE_H
 
 #include "definitions.h"
+#include "jobs/taskmanager.h"
 #include "kdenlivecore_export.h"
 #include "undohelper.hpp"
 #include <QMutex>
@@ -20,6 +21,7 @@ the Free Software Foundation, either version 3 of the License, or
 #include <QUrl>
 #include <memory>
 #include <QPoint>
+#include <QThreadPool>
 #include <QTextEdit>
 #include <KSharedDataCache>
 #include <unordered_set>
@@ -28,7 +30,6 @@ the Free Software Foundation, either version 3 of the License, or
 class Bin;
 class DocUndoStack;
 class EffectStackModel;
-class JobManager;
 class KdenliveDoc;
 class LibraryWidget;
 class MainWindow;
@@ -42,6 +43,7 @@ class ProjectManager;
 class SubtitleEdit;
 class SubtitleModel;
 class TextBasedEdit;
+class TimeRemap;
 
 namespace Mlt {
     class Repository;
@@ -60,7 +62,6 @@ namespace Mlt {
  * Needs to be initialize before any widgets are created in MainWindow.
  * Plugins should be loaded after the widget setup.
  */
-
 class /*KDENLIVECORE_EXPORT*/ Core : public QObject
 {
     Q_OBJECT
@@ -115,14 +116,14 @@ public:
     void selectTimelineItem(int id);
     /** @brief Returns a pointer to the model of the project bin. */
     std::shared_ptr<ProjectItemModel> projectItemModel();
-    /** @brief Returns a pointer to the job manager. Please do not store it. */
-    std::shared_ptr<JobManager> jobManager();
     /** @brief Returns a pointer to the library. */
     LibraryWidget *library();
     /** @brief Returns a pointer to the subtitle edit. */
     SubtitleEdit *subtitleWidget();
     /** @brief Returns a pointer to the text based editing widget. */
     TextBasedEdit *textEditWidget();
+    /** @brief Returns a pointer to the time remapping widget. */
+    TimeRemap *timeRemapWidget();
     /** @brief Returns a pointer to the audio mixer. */
     MixerManager *mixer();
 
@@ -248,6 +249,10 @@ public:
     /** @brief Display key binding info in statusbar. */
     void setWidgetKeyBinding(const QString &mess = QString());
     KSharedDataCache audioThumbCache;
+    /* @brief The thread job pool for clip jobs, allowing to set a max number of concurrent jobs */
+    TaskManager taskManager;
+    /** @brief The number of clip load jobs changed */
+    void loadingClips(int);
 
 private:
     explicit Core();
@@ -260,12 +265,13 @@ private:
     ProjectManager *m_projectManager{nullptr};
     MonitorManager *m_monitorManager{nullptr};
     std::shared_ptr<ProjectItemModel> m_projectItemModel;
-    std::shared_ptr<JobManager> m_jobManager;
     Bin *m_binWidget{nullptr};
     LibraryWidget *m_library{nullptr};
     SubtitleEdit *m_subtitleWidget{nullptr};
     TextBasedEdit *m_textEditWidget{nullptr};
+    TimeRemap *m_timeRemapWidget{nullptr};
     MixerManager *m_mixerWidget{nullptr};
+
     /** @brief Current project's profile path */
     QString m_currentProfile;
 
@@ -296,6 +302,8 @@ public slots:
     /** @brief Show currently selected effect zone in timeline ruler. */
     void showEffectZone(ObjectId id, QPair <int, int>inOut, bool checked);
     void updateMasterZones();
+    /** @brief Open the proxies test dialog. */
+    void testProxies();
 
 signals:
     void coreIsReady();
@@ -317,6 +325,9 @@ signals:
     void updateEffectZone(const QPoint p, bool withUndo);
     /** @brief The effect stask is about to be deleted, disconnect everything */
     void disconnectEffectStack();
+    /** @brief Add a time remap effect to clip and show keyframes dialog */
+    void remapClip(int cid);
+
 };
 
 #endif
