@@ -17,10 +17,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-/*! \class KdenliveDoc
-    \brief Represents a kdenlive project file
-
-   Instances of KdenliveDoc classes are created by void MainWindow::newFile(bool showProjectSettings, bool force)
+/** @class KdenliveDoc
+ *  @brief Represents a kdenlive project file
+ *
+ *  Instances of KdenliveDoc classes are created by void MainWindow::newFile(bool showProjectSettings, bool force)
 */
 #ifndef KDENLIVEDOC_H
 #define KDENLIVEDOC_H
@@ -29,6 +29,7 @@
 #include <QDir>
 #include <QList>
 #include <QMap>
+#include <QUuid>
 #include <memory>
 #include <qdom.h>
 
@@ -69,7 +70,10 @@ public:
     int width() const;
     int height() const;
     QUrl url() const;
+    QUuid uuid;
     KAutoSaveFile *m_autosave;
+    /** @brief Whether the project folder should be in the same folder as the project file (var is only used for new projects)*/
+    bool m_sameProjectFolder;
     Timecode timecode() const;
     std::shared_ptr<DocUndoStack> commandStack();
 
@@ -231,21 +235,24 @@ public slots:
     void slotCreateTextTemplateClip(const QString &group, const QString &groupId, QUrl path);
 
     /** @brief Sets the document as modified or up to date.
-     * @description  If crash recovery is turned on, a timer calls KdenliveDoc::slotAutoSave() \n
+     *  
+     * If crash recovery is turned on, a timer calls KdenliveDoc::slotAutoSave() \n
      * Emits docModified connected to MainWindow::slotUpdateDocumentState \n
+     * 
      * @param mod (optional) true if the document has to be saved */
     void setModified(bool mod = true);
     void slotProxyCurrentItem(bool doProxy, QList<std::shared_ptr<ProjectClip>> clipList = QList<std::shared_ptr<ProjectClip>>(), bool force = false,
                               QUndoCommand *masterCommand = nullptr);
     /** @brief Saves the current project at the autosave location.
-     * @description The autosave files are in ~/.kde/data/stalefiles/kdenlive/ */
+     * 
+     * The autosave files are in ~/.kde/data/stalefiles/kdenlive/ */
     void slotAutoSave(const QString &scene);
     /** @brief Groups were changed, save to MLT. */
     void groupsChanged(const QString &groups);
+    void switchProfile(ProfileParam* pf);
 
 private slots:
     void slotModified();
-    void switchProfile(std::unique_ptr<ProfileParam> &profile, const QString &id, const QDomElement &xml);
     void slotSwitchProfile(const QString &profile_path, bool reloadThumbs);
     /** @brief Check if we did a new action invalidating more recent undo items. */
     void checkPreviewStack(int ix);
