@@ -39,6 +39,7 @@
 #include "monitorproxy.h"
 #include "profiles/profilemodel.hpp"
 #include "timeline2/view/qml/timelineitems.h"
+#include "timeline2/view/qmltypes/thumbnailprovider.h"
 #include <mlt++/Mlt.h>
 #include <lib/localeHandling.h>
 
@@ -146,6 +147,7 @@ GLWidget::GLWidget(int id, QObject *parent)
     registerTimelineItems();
     m_proxy = new MonitorProxy(this);
     rootContext()->setContextProperty("controller", m_proxy);
+    engine()->addImageProvider(QStringLiteral("thumbnail"), new ThumbnailProvider);
 }
 
 GLWidget::~GLWidget()
@@ -418,7 +420,7 @@ bool GLWidget::acquireSharedFrameTextures()
         // C & D
         m_contextSharedAccess.lock();
         if (m_sharedFrame.is_valid()) {
-            m_texture[0] = *(reinterpret_cast<const GLuint *>(m_sharedFrame.get_image(mlt_image_glsl_texture)));
+            m_texture[0] = *(reinterpret_cast<const GLuint *>(m_sharedFrame.get_image(mlt_image_opengl_texture)));
         }
     }
 
@@ -654,7 +656,11 @@ bool GLWidget::isReady() const
 
 void GLWidget::requestSeek(int position)
 {
-    m_consumer->set("scrub_audio", 1);
+    if(KdenliveSettings::audio_scrub()){
+        m_consumer->set("scrub_audio", 1);
+    } else {
+        m_consumer->set("scrub_audio", 0);
+    }
     m_producer->seek(position);
     if (!qFuzzyIsNull(m_producer->get_speed())) {
         m_consumer->purge();
@@ -1131,7 +1137,7 @@ int GLWidget::reconfigure()
 
         delete m_threadCreateEvent;
         delete m_threadJoinEvent;
-        if (m_consumer) {
+        if (m_glslManager) {
             m_threadCreateEvent = m_consumer->listen("consumer-thread-create", this, mlt_listener(onThreadCreate));
             m_threadJoinEvent = m_consumer->listen("consumer-thread-join", this, mlt_listener(onThreadJoin));
         }
@@ -1206,7 +1212,11 @@ int GLWidget::reconfigure()
         m_consumer->set("buffer", qMax(25, fps));
         m_consumer->set("prefill", qMax(1, fps / 25));
         m_consumer->set("drop_max", fps / 4);
-        m_consumer->set("scrub_audio", 1);
+        if (KdenliveSettings::audio_scrub()) {
+            m_consumer->set("scrub_audio", 1);
+        } else {
+            m_consumer->set("scrub_audio", 0);
+        }
         if (KdenliveSettings::monitor_gamma() == 0) {
             m_consumer->set("color_trc", "iec61966_2_1");
         } else {
@@ -1627,7 +1637,7 @@ void GLWidget::switchPlay(bool play, int offset, double speed)
         resetZoneMode();
     }
     if (play) {
-        if (m_id == Kdenlive::ClipMonitor && m_consumer->position() == m_producer->get_out() - offset && speed > 0) {
+        if ((m_id == Kdenlive::ClipMonitor || (m_id == Kdenlive::ProjectMonitor && KdenliveSettings::jumptostart())) && m_consumer->position() == m_producer->get_out() - offset && speed > 0) {
             m_producer->seek(0);
         }
         qDebug() << "pos: " << m_consumer->position() << "out-offset: " << m_producer->get_out() - offset;
@@ -1636,7 +1646,7 @@ void GLWidget::switchPlay(bool play, int offset, double speed)
         m_proxy->setSpeed(speed);
         if (qFuzzyCompare(speed, 1.0) || speed < -6. || speed > 6.) {
             m_consumer->set("scrub_audio", 0);
-        } else {
+        } else if (KdenliveSettings::audio_scrub()){
             m_consumer->set("scrub_audio", 1);
         }
         if (qFuzzyIsNull(current_speed)) {
@@ -1847,7 +1857,6 @@ void GLWidget::setConsumerProperty(const QString &name, const QString &value)
 
 bool GLWidget::updateScaling()
 {
-#if LIBMLT_VERSION_INT >= QT_VERSION_CHECK(6,20,0)
     int previewHeight = pCore->getCurrentFrameSize().height();
     switch (KdenliveSettings::previewScaling()) {
         case 2:
@@ -1879,21 +1888,6 @@ bool GLWidget::updateScaling()
         m_consumer->set("height", m_profileSize.height());
         resizeGL(width(), height());
     }
-#else
-    int previewHeight = pCore->getCurrentFrameSize().height();
-    int pWidth = previewHeight * pCore->getCurrentDar() / pCore->getCurrentSar();
-    if (pWidth% 2 > 0) {
-        pWidth ++;
-    }
-    QSize profileSize(pWidth, previewHeight);
-    if (profileSize == m_profileSize) {
-        return false;
-    }
-    m_profileSize = profileSize;
-    if (m_consumer) {
-        resizeGL(width(), height());
-    }
-#endif
     return true;
 }
 
