@@ -13,7 +13,6 @@ the Free Software Foundation, either version 3 of the License, or
 #include "bin/projectitemmodel.h"
 #include "core.h"
 #include "doc/kdenlivedoc.h"
-#include "jobs/jobmanager.h"
 #include "kdenlivesettings.h"
 #include "mainwindow.h"
 #include "monitor/monitormanager.h"
@@ -160,6 +159,7 @@ void ProjectManager::newFile(QString profileName, bool showProjectSettings)
     pCore->monitorManager()->resetDisplay();
     QString documentId = QString::number(QDateTime::currentMSecsSinceEpoch());
     documentProperties.insert(QStringLiteral("documentid"), documentId);
+    bool sameProjectFolder = KdenliveSettings::sameprojectfolder();
     if (!showProjectSettings) {
         if (!closeCurrentDocument()) {
             return;
@@ -211,6 +211,7 @@ void ProjectManager::newFile(QString profileName, bool showProjectSettings)
             }
             documentProperties.insert(QStringLiteral("storagefolder"), projectFolder + documentId);
         }
+        sameProjectFolder = w->docFolderAsStorageFolder();
         documentMetadata = w->metadata();
         delete w;
     }
@@ -219,6 +220,7 @@ void ProjectManager::newFile(QString profileName, bool showProjectSettings)
     pCore->bin()->cleanDocument();
     KdenliveDoc *doc = new KdenliveDoc(QUrl(), projectFolder, pCore->window()->m_commandStack, profileName, documentProperties, documentMetadata, projectTracks, audioChannels, &openBackup, pCore->window());
     doc->m_autosave = new KAutoSaveFile(startFile, doc);
+    doc->m_sameProjectFolder = sameProjectFolder;
     ThumbnailCache::get()->clearCache();
     pCore->bin()->setDocument(doc);
     m_project = doc;
@@ -265,13 +267,12 @@ bool ProjectManager::closeCurrentDocument(bool saveChanges, bool quit)
     }
     ::mlt_pool_purge();
     pCore->audioThumbCache.clear();
-    pCore->jobManager()->slotCancelJobs();
+    pCore->taskManager.slotCancelJobs();
     disconnect(pCore->window()->getMainTimeline()->controller(), &TimelineController::durationChanged, this, &ProjectManager::adjustProjectDuration);
     pCore->window()->getMainTimeline()->controller()->clipActions.clear();
     if (!quit && !qApp->isSavingSession()) {
         m_autoSaveTimer.stop();
         if (m_project) {
-            pCore->jobManager()->slotCancelJobs();
             pCore->bin()->abortOperations();
         }
     }
@@ -299,6 +300,11 @@ bool ProjectManager::closeCurrentDocument(bool saveChanges, bool quit)
 bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveACopy)
 {
     pCore->monitorManager()->pauseActiveMonitor();
+    QString oldProjectFolder = m_project->url().isEmpty()
+            ? QString()
+            : QFileInfo(m_project->url().toLocalFile()).absolutePath() + QStringLiteral("/cachefiles");
+            // this was the old project folder in case the "save in project file location" setting was active
+
     // Sync document properties
     if (!saveACopy && outputFileName != m_project->url().toLocalFile()) {
         // Project filename changed
@@ -348,6 +354,32 @@ bool ProjectManager::saveFileAs(const QString &outputFileName, bool saveACopy)
     if (!saveACopy) {
         m_fileRevert->setEnabled(true);
         pCore->window()->m_undoView->stack()->setClean();
+        QString newProjectFolder(saveFolder + QStringLiteral("/cachefiles"));
+        if(((oldProjectFolder.isEmpty() && m_project->m_sameProjectFolder) || m_project->projectTempFolder() == oldProjectFolder) && newProjectFolder != m_project->projectTempFolder()) {
+            KMessageBox::ButtonCode answer = KMessageBox::warningContinueCancel(
+                pCore->window(), i18n("The location of the project file changed. You selected to use the location of the project file to save temporary files. "
+                           "This will move all temporary files from <b>%1</b> to <b>%2</b>, the project file will then be reloaded",
+                           m_project->projectTempFolder(), newProjectFolder));
+
+            if (answer == KMessageBox::Continue) {
+                // Proceed with move
+                QString documentId = QDir::cleanPath(m_project->getDocumentProperty(QStringLiteral("documentid")));
+                bool ok;
+                documentId.toLongLong(&ok, 10);
+                if (!ok || documentId.isEmpty()) {
+                    KMessageBox::sorry(pCore->window(), i18n("Cannot perform operation, invalid document id: %1", documentId));
+                } else {
+                    QDir newDir(newProjectFolder);
+                    QDir oldDir(m_project->projectTempFolder());
+                    if (newDir.exists(documentId)) {
+                        KMessageBox::sorry(pCore->window(), i18n("Cannot perform operation, target directory already exists: %1", newDir.absoluteFilePath(documentId)));
+                    } else {
+                        // Proceed with the move
+                        pCore->projectManager()->moveProjectData(oldDir.absoluteFilePath(documentId), newDir.absolutePath());
+                    }
+                }
+            }
+        }
     }
 
     return true;
@@ -901,7 +933,7 @@ void ProjectManager::slotMoveFinished(KJob *job)
 bool ProjectManager::updateTimeline(int pos, int scrollPos)
 {
     Q_UNUSED(scrollPos);
-    pCore->jobManager()->slotCancelJobs();
+    pCore->taskManager.slotCancelJobs();
     pCore->window()->getMainTimeline()->loading = true;
     pCore->window()->slotSwitchTimelineZone(m_project->getDocumentProperty(QStringLiteral("enableTimelineZone")).toInt() == 1);
 
