@@ -31,7 +31,6 @@
 #else
 #define TRACE_CONSTR(...)
 #endif
-#include "jobs/jobmanager.h"
 #include "snapmodel.hpp"
 #include "timelinemodel.hpp"
 #include <QDebug>
@@ -439,7 +438,7 @@ bool TrackModel::requestClipDeletion(int clipId, bool updateView, bool finalMove
     // qDebug() << "/// REQUESTOING CLIP DELETION_: " << updateView;
     int duration = trackDuration();
     if (finalDeletion) {
-        pCore->jobManager()->slotDiscardClipJobs(m_allClips[clipId]->binId(), {ObjectType::TimelineClip,clipId});
+        pCore->taskManager.discardJobs({ObjectType::TimelineClip,clipId});
     }
     auto operation = requestClipDeletion_lambda(clipId, updateView, finalMove, groupMove, finalDeletion);
     if (operation()) {
@@ -458,14 +457,27 @@ int TrackModel::getBlankSizeAtPos(int frame)
 {
     READ_LOCK();
     int min_length = 0;
+    int blank_length = 0;
     for (auto &m_playlist : m_playlists) {
-        int ix = m_playlist.get_clip_index_at(frame);
-        if (m_playlist.is_blank(ix)) {
-            int blank_length = m_playlist.clip_length(ix);
-            if (min_length == 0 || (blank_length > 0 && blank_length < min_length)) {
-                min_length = blank_length;
+        int playlistLength = m_playlist.get_length();
+        if (frame >= playlistLength) {
+            continue;
+        } else {
+            int ix = m_playlist.get_clip_index_at(frame);
+            if (m_playlist.is_blank(ix)) {
+                blank_length = m_playlist.clip_length(ix);
+            } else {
+                // There is a clip at that position, abort
+                return 0;
             }
         }
+        if (min_length == 0 || blank_length < min_length) {
+            min_length = blank_length;
+        }
+    }
+    if (blank_length == 0) {
+        // playlists are shorter than frame
+        return -1;
     }
     return min_length;
 }
@@ -1046,7 +1058,7 @@ bool TrackModel::checkConsistency()
     int mixCount = 0;
     qDebug()<<"=== STARTING MIX CHECK ======";
     while (service != nullptr && service->is_valid()) {
-        if (service->type() == transition_type) {
+        if (service->type() == mlt_service_transition_type) {
             Mlt::Transition t(mlt_transition(service->get_service()));
             service.reset(service->producer());
             // Check that the mix has correct in/out
