@@ -89,6 +89,7 @@ class TimelineController : public QObject
     Q_PROPERTY(QColor groupColor READ groupColor NOTIFY colorsChanged)
     Q_PROPERTY(bool subtitlesDisabled READ subtitlesDisabled NOTIFY subtitlesDisabledChanged)
     Q_PROPERTY(bool subtitlesLocked READ subtitlesLocked NOTIFY subtitlesLockedChanged)
+    Q_PROPERTY(bool guidesLocked READ guidesLocked NOTIFY guidesLockedChanged)
     Q_PROPERTY(QPoint effectZone MEMBER m_effectZone NOTIFY effectZoneChanged)
 
 public:
@@ -191,6 +192,7 @@ public:
     bool subtitlesDisabled() const;
     void switchSubtitleLock();
     bool subtitlesLocked() const;
+    bool guidesLocked() const;
     /** @brief Request a seek operation
        @param position is the desired new timeline position
      */
@@ -340,7 +342,7 @@ public:
     Q_INVOKABLE void adjustAllTrackHeight(int trackId, int height);
     Q_INVOKABLE void collapseAllTrackHeight(int trackId, bool collapse, int collapsedHeight);
 
-    /** @brief Reset track @trackId height to default track height. Adjusts all tracks if @trackId == -1
+    /** @brief Reset track \@trackId height to default track height. Adjusts all tracks if \@trackId == -1
     */
     Q_INVOKABLE void defaultTrackHeight(int trackId);
 
@@ -394,9 +396,21 @@ public:
     /** @brief Request a spacer operation
      */
     Q_INVOKABLE int requestSpacerStartOperation(int trackId, int position);
+    /** @brief Returns the minimum available position for a spacer operation
+     */
+    Q_INVOKABLE int spacerMinPos() const;
+    /** @brief Get a list of guides Id after a given frame
+     */
+    Q_INVOKABLE QVector<int> spacerSelection(int startFrame);
+    /** @brief Move a list of guides from a given offset
+     */
+    Q_INVOKABLE void spacerMoveGuides(QVector<int> ids, int offset);
+    /** @brief Get the position of the first marker in the list
+     */
+    Q_INVOKABLE int getGuidePosition(int ids);
     /** @brief Request a spacer operation
      */
-    Q_INVOKABLE bool requestSpacerEndOperation(int clipId, int startPosition, int endPosition, int affectedTrack, int guideStart = -1);
+    Q_INVOKABLE bool requestSpacerEndOperation(int clipId, int startPosition, int endPosition, int affectedTrack, QVector<int> selectedGuides = QVector<int>(), int guideStart = -1);
     /** @brief Request a Fade in effect for clip
      */
     Q_INVOKABLE void adjustFade(int cid, const QString &effectId, int duration, int initialDuration);
@@ -486,6 +500,9 @@ public:
     /** @brief Returns a list of all luma files used in the project
      */
     QStringList extractCompositionLumas() const;
+    /** @brief Returns a list of all external files used by effects in the timeline
+     */
+    QStringList extractExternalEffectFiles() const;
     /** @brief Get the frame where mouse is positioned
      */
     int getMousePos();
@@ -542,6 +559,8 @@ public:
 
     /** @brief Change a clip item's speed in timeline */
     Q_INVOKABLE void changeItemSpeed(int clipId, double speed);
+    /** @brief Activate time remap on the clip */
+    void remapItemTime(int clipId, double speed);
     /** @brief Delete selected zone and fill gap by moving following clips
      *  @param lift if true, the zone will simply be deleted but clips won't be moved
      */
@@ -608,7 +627,7 @@ public:
     Q_INVOKABLE void resizeSubtitle(int startFrame, int endFrame, int oldEndFrame, bool refreshModel);
     /** @brief Add subtitle clip at cursor's position in timeline */
     Q_INVOKABLE void addSubtitle(int startframe = -1, QString text = QString());
-    /** @brief Cut a subtitle and split the text at @param pos */
+    /** @brief Cut a subtitle and split the text at \@param pos */
     void cutSubtitle(int id, int cursorPos);
     /** @brief Delete subtitle clip with frame as start position*/
     Q_INVOKABLE void deleteSubtitle(int frameframe, int endframe, QString Ctext);
@@ -668,7 +687,6 @@ private:
     bool m_usePreview;
     int m_audioTarget;
     int m_videoTarget;
-    int m_activeTrack;
     int m_audioRef;
     int m_hasAudioTarget {0};
     bool m_hasVideoTarget {false};
@@ -680,6 +698,7 @@ private:
     QPair<int, int> m_recordStart;
     int m_recordTrack;
     QPoint m_zone;
+    int m_activeTrack;
     double m_scale;
     static int m_duration;
     PreviewManager *m_timelinePreview;
@@ -750,6 +769,7 @@ signals:
     /** @brief Center timeline view on current position
      */
     void centerView();
+    void guidesLockedChanged();
     void effectZoneChanged();
     void masterZonesChanged();
     Q_INVOKABLE void ungrabHack();
